@@ -2,7 +2,7 @@
 Core entity types.
 """
 import abc
-from typing import TYPE_CHECKING, Type, Mapping
+from typing import TYPE_CHECKING, Type, Mapping, Tuple, Any, Dict
 
 if TYPE_CHECKING:
     from aiogram.filters import Filter
@@ -20,9 +20,9 @@ class Entity:  # pylint: disable=too-few-public-methods
 
 class EntityContainer(abc.ABC):  # pylint: disable=too-few-public-methods
     """Base class for Entity container implementation."""
-    state: Type['EntityContainerStatesGroup'] = None
+    state: Type['EntityContainerStatesGroup'] = None  # type: ignore[assignment]
 
     @classmethod
     @abc.abstractmethod
-    def filters(cls, *args, **kwargs) -> Mapping['RouterHandlerType', 'Filter']:
+    def filters(cls, *args: Tuple[Any], **kwargs: Dict[str, Any]) -> Mapping['RouterHandlerType', 'Filter']:
         """Event filters."""
