@@ -2,6 +2,6 @@
 General types.
 """
 from typing import Union
-from aiogram.utils.i18n.lazy_proxy import LazyProxy
+from aiogram.utils.i18n.lazy_proxy import LazyProxy  # type: ignore[attr-defined]
 
 TranslatableString = Union[str, LazyProxy]
