@@ -4,7 +4,7 @@ Utilities and helpers.
 from typing import Any, Type, Tuple
 
 
-def get_attrs_of_type(obj: Any, type_: Type) -> Tuple:
+def get_attrs_of_type(obj: Any, type_: Type) -> Tuple:  # type: ignore[type-arg]
     """Get object attrs of given type."""
     return tuple(
         (key, value)
